==> singularity-logfetch-0.21.0.tar.gz: singularity-logfetch-0.21.0/logfetch/s3_logs.py <==
import os
import sys
import grequests
import logfetch_base
import time
from termcolor import colored
import callbacks
from singularity_request import get_json_response

TASK_FORMAT = '/task/{0}'
S3LOGS_URI_FORMAT = '{0}/logs{1}'
REQUEST_FORMAT = '/request/{0}'

FILE_REGEX="\d{13}-([^-]*)-\d{8,20}\.gz"

progress = 0
goal = 0

def download_s3_logs(args):
  sys.stderr.write(colored('Checking for S3 log files', 'cyan') + '\n')
  callbacks.progress = 0
  logs = logs_for_all_requests(args)
  async_requests = []
  zipped_files = []
  all_logs = []
  for log_file in logs:
    filename = log_file['key'].rsplit("/", 1)[1]
    if logfetch_base.is_in_date_range(args, int(str(log_file['lastModified'])[0:-3])):
      if not args.logtype or log_matches(args, filename):
        if args.verbose:
          sys.stderr.write(colored('Including log {0}'.format(filename), 'blue') + '\n')
        if not already_downloaded(args.dest, filename):
          async_requests.append(
            grequests.AsyncRequest('GET', log_file['getUrl'], callback=callbacks.generate_callback(log_file['getUrl'], args.dest, filename, args.chunk_size, args.verbose), headers=args.headers)
          )
        else:
          if args.verbose:
            sys.stderr.write(colored('Log already downloaded {0}'.format(filename), 'blue') + '\n')
          all_logs.append('{0}/{1}'.format(args.dest, filename.replace('.gz', '.log')))
        zipped_files.append('{0}/{1}'.format(args.dest, filename))
      else:
        if args.verbose:
          sys.stderr.write(colored('Excluding {0} log does not match logtype argument {1}'.format(filename, args.logtype), 'magenta') + '\n')
    else:
      if args.verbose:
        sys.stderr.write(colored('Excluding {0}, not in date range'.format(filename), 'magenta') + '\n')
  if async_requests:
    sys.stderr.write(colored('Starting {0} S3 Downloads with {1} parallel fetches\n'.format(len(async_requests), args.num_parallel_fetches), 'cyan'))
    callbacks.goal = len(async_requests)
    grequests.map(async_requests, stream=True, size=args.num_parallel_fetches)
    sys.stderr.write(colored('\nUnpacking {0} S3 log(s)\n'.format(len(async_requests)), 'cyan'))
  else:
    sys.stderr.write(colored('No S3 logs to download\n', 'cyan'))
  all_logs = all_logs + logfetch_base.unpack_logs(args, zipped_files)
  sys.stderr.write(colored('All S3 logs up to date\n', 'cyan'))
  return all_logs

def already_downloaded(dest, filename):
  return (os.path.isfile('{0}/{1}'.format(dest, filename.replace('.gz', '.log'))) or os.path.isfile('{0}/{1}'.format(dest, filename)))

def logs_for_all_requests(args):
  s3_params = {'start': int(time.mktime(args.start.timetuple()) * 1000), 'end': int(time.mktime(args.end.timetuple()) * 1000)}
  if args.taskId:
    return get_json_response(s3_task_logs_uri(args, args.taskId), args, s3_params)
  else:
    tasks = logfetch_base.tasks_for_requests(args)
    logs = []
    tasks_progress = 0
    tasks_goal = len(tasks)
    for task in tasks:
      s3_logs = get_json_response(s3_task_logs_uri(args, task), args, s3_params)
      logs = logs + s3_logs if s3_logs else logs
      tasks_progress += 1
      logfetch_base.update_progress_bar(tasks_progress, tasks_goal, 'S3 Log Finder')
    sys.stderr.write(colored('\nAlso searching s3 history...\n', 'cyan'))
    for request in logfetch_base.all_requests(args):
      s3_logs = get_json_response(s3_request_logs_uri(args, request), args, s3_params)
      logs = logs + s3_logs if s3_logs else logs
    return [dict(t) for t in set([tuple(l.items()) for l in logs])] # remove any duplicates

def s3_task_logs_uri(args, idString):
  return S3LOGS_URI_FORMAT.format(logfetch_base.base_uri(args), TASK_FORMAT.format(idString))

def s3_request_logs_uri(args, idString):
  return S3LOGS_URI_FORMAT.format(logfetch_base.base_uri(args), REQUEST_FORMAT.format(idString))

def log_matches(args, filename):
  if 'filename' in args.file_pattern:
    return logfetch_base.log_matches(filename, '*{0}*'.format(args.logtype.replace('logs/', '')))
  else:
    sys.stderr.write(colored('Cannot match on log file names for s3 logs when filename is not in s3 pattern', 'red'))
    if args.no_name_fetch_off:
      sys.stderr.write(colored('Will not fetch any s3 logs beacuse --no-name-fetch-off is set, remove this setting to fetch all for this case instead', 'red'))
      return False
    else:
      sys.stderr.write(colored('Will fetch all s3 logs, set --no-name-fetch-off to skip s3 logs instead for this case', 'red'))
      return True

==> singularity-logfetch-0.22.0.tar.gz: singularity-logfetch-0.22.0/logfetch/s3_logs.py <==
import os
import sys
import grequests
import logfetch_base
import time
from termcolor import colored
import callbacks
from singularity_request import get_json_response

TASK_FORMAT = '/task/{0}'
S3LOGS_URI_FORMAT = '{0}/logs{1}'
REQUEST_FORMAT = '/request/{0}'

FILE_REGEX="\d{13}-([^-]*)-\d{8,20}\.gz"

progress = 0
goal = 0

def download_s3_logs(args):
  if not args.silent:
    sys.stderr.write(colored('Checking for S3 log files', 'cyan') + '\n')
  callbacks.progress = 0
  logs = logs_for_all_requests(args)
  async_requests = []
  zipped_files = []
  all_logs = []
  for log_file in logs:
    filename = log_file['key'].rsplit("/", 1)[1]
    if logfetch_base.is_in_date_range(args, int(str(log_file['lastModified'])[0:-3])):
      if not args.logtype or log_matches(args, filename):
        if args.verbose and not args.silent:
          sys.stderr.write(colored('Including log {0}'.format(filename), 'blue') + '\n')
        if not already_downloaded(args.dest, filename):
          async_requests.append(
            grequests.AsyncRequest('GET', log_file['getUrl'], callback=callbacks.generate_callback(log_file['getUrl'], args.dest, filename, args.chunk_size, args.verbose, args.silent), headers=args.headers)
          )
        else:
          if args.verbose and not args.silent:
            sys.stderr.write(colored('Log already downloaded {0}'.format(filename), 'blue') + '\n')
          all_logs.append('{0}/{1}'.format(args.dest, filename.replace('.gz', '.log')))
        zipped_files.append('{0}/{1}'.format(args.dest, filename))
      else:
        if args.verbose and not args.silent:
          sys.stderr.write(colored('Excluding {0} log does not match logtype argument {1}'.format(filename, args.logtype), 'magenta') + '\n')
    else:
      if args.verbose and not args.silent:
        sys.stderr.write(colored('Excluding {0}, not in date range'.format(filename), 'magenta') + '\n')
  if async_requests:
    if not args.silent:
      sys.stderr.write(colored('Starting {0} S3 Downloads with {1} parallel fetches\n'.format(len(async_requests), args.num_parallel_fetches), 'cyan'))
    callbacks.goal = len(async_requests)
    grequests.map(async_requests, stream=True, size=args.num_parallel_fetches)
    if not args.silent:
      sys.stderr.write(colored('\nUnpacking {0} S3 log(s)\n'.format(len(async_requests)), 'cyan'))
  else:
    if not args.silent:
      sys.stderr.write(colored('No S3 logs to download\n', 'cyan'))
  all_logs = all_logs + logfetch_base.unpack_logs(args, zipped_files)
  if not args.silent:
    sys.stderr.write(colored('All S3 logs up to date\n', 'cyan'))
  return all_logs

def already_downloaded(dest, filename):
  return (os.path.isfile('{0}/{1}'.format(dest, filename.replace('.gz', '.log'))) or os.path.isfile('{0}/{1}'.format(dest, filename)))

def logs_for_all_requests(args):
  s3_params = {'start': int(time.mktime(args.start.timetuple()) * 1000), 'end': int(time.mktime(args.end.timetuple()) * 1000)}
  if args.taskId:
    return get_json_response(s3_task_logs_uri(args, args.taskId), args, s3_params)
  else:
    tasks = logfetch_base.tasks_for_requests(args)
    logs = []
    tasks_progress = 0
    tasks_goal = len(tasks)
    for task in tasks:
      s3_logs = get_json_response(s3_task_logs_uri(args, task), args, s3_params)
      logs = logs + s3_logs if s3_logs else logs
      tasks_progress += 1
      logfetch_base.update_progress_bar(tasks_progress, tasks_goal, 'S3 Log Finder', args.silent)
    if not args.silent:
      sys.stderr.write(colored('\nAlso searching s3 history...\n', 'cyan'))
    for request in logfetch_base.all_requests(args):
      s3_logs = get_json_response(s3_request_logs_uri(args, request), args, s3_params)
      logs = logs + s3_logs if s3_logs else logs
    return [dict(t) for t in set([tuple(l.items()) for l in logs])] # remove any duplicates

def s3_task_logs_uri(args, idString):
  return S3LOGS_URI_FORMAT.format(logfetch_base.base_uri(args), TASK_FORMAT.format(idString))

def s3_request_logs_uri(args, idString):
  return S3LOGS_URI_FORMAT.format(logfetch_base.base_uri(args), REQUEST_FORMAT.format(idString))

def log_matches(args, filename):
  if 'filename' in args.file_pattern:
    return logfetch_base.log_matches(filename, '*{0}*'.format(args.logtype.replace('logs/', '')))
  else:
    sys.stderr.write(colored('Cannot match on log file names for s3 logs when filename is not in s3 pattern', 'red'))
    if args.no_name_fetch_off:
      sys.stderr.write(colored('Will not fetch any s3 logs beacuse --no-name-fetch-off is set, remove this setting to fetch all for this case instead', 'red'))
      return False
    else:
      sys.stderr.write(colored('Will fetch all s3 logs, set --no-name-fetch-off to skip s3 logs instead for this case', 'red'))
      return True
